==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkImageViewer.java <==
// java wrapper for vtkImageViewer object
//

package vtk;
import vtk.*;

public class vtkImageViewer extends vtkObject
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native String GetWindowName_2();
  public String GetWindowName()
    { return GetWindowName_2(); }

  private native void Render_3();
  public void Render()
    { Render_3(); }

  private native void SetInputData_4(vtkImageData id0);
  public void SetInputData(vtkImageData id0)
    { SetInputData_4(id0); }

  private native long GetInput_5();
  public vtkImageData GetInput() {
    long temp = GetInput_5();

    if (temp == 0) return null;
    return (vtkImageData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetInputConnection_6(vtkAlgorithmOutput id0);
  public void SetInputConnection(vtkAlgorithmOutput id0)
    { SetInputConnection_6(id0); }

  private native int GetWholeZMin_7();
  public int GetWholeZMin()
    { return GetWholeZMin_7(); }

  private native int GetWholeZMax_8();
  public int GetWholeZMax()
    { return GetWholeZMax_8(); }

  private native int GetZSlice_9();
  public int GetZSlice()
    { return GetZSlice_9(); }

  private native void SetZSlice_10(int id0);
  public void SetZSlice(int id0)
    { SetZSlice_10(id0); }

  private native double GetColorWindow_11();
  public double GetColorWindow()
    { return GetColorWindow_11(); }

  private native double GetColorLevel_12();
  public double GetColorLevel()
    { return GetColorLevel_12(); }

  private native void SetColorWindow_13(double id0);
  public void SetColorWindow(double id0)
    { SetColorWindow_13(id0); }

  private native void SetColorLevel_14(double id0);
  public void SetColorLevel(double id0)
    { SetColorLevel_14(id0); }

  private native int[]  GetPosition_15();
  public int[]  GetPosition()
    { return GetPosition_15(); }

  private native void SetPosition_16(int id0,int id1);
  public void SetPosition(int id0,int id1)
    { SetPosition_16(id0,id1); }

  private native void SetPosition_17(int id0[]);
  public void SetPosition(int id0[])
    { SetPosition_17(id0); }

  private native int[]  GetSize_18();
  public int[]  GetSize()
    { return GetSize_18(); }

  private native void SetSize_19(int id0,int id1);
  public void SetSize(int id0,int id1)
    { SetSize_19(id0,id1); }

  private native void SetSize_20(int id0[]);
  public void SetSize(int id0[])
    { SetSize_20(id0); }

  private native long GetRenderWindow_21();
  public vtkRenderWindow GetRenderWindow() {
    long temp = GetRenderWindow_21();

    if (temp == 0) return null;
    return (vtkRenderWindow)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetRenderer_22();
  public vtkRenderer GetRenderer() {
    long temp = GetRenderer_22();

    if (temp == 0) return null;
    return (vtkRenderer)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetImageMapper_23();
  public vtkImageMapper GetImageMapper() {
    long temp = GetImageMapper_23();

    if (temp == 0) return null;
    return (vtkImageMapper)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetActor2D_24();
  public vtkActor2D GetActor2D() {
    long temp = GetActor2D_24();

    if (temp == 0) return null;
    return (vtkActor2D)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetupInteractor_25(vtkRenderWindowInteractor id0);
  public void SetupInteractor(vtkRenderWindowInteractor id0)
    { SetupInteractor_25(id0); }

  private native void SetOffScreenRendering_26(int id0);
  public void SetOffScreenRendering(int id0)
    { SetOffScreenRendering_26(id0); }

  private native int GetOffScreenRendering_27();
  public int GetOffScreenRendering()
    { return GetOffScreenRendering_27(); }

  private native void OffScreenRenderingOn_28();
  public void OffScreenRenderingOn()
    { OffScreenRenderingOn_28(); }

  private native void OffScreenRenderingOff_29();
  public void OffScreenRenderingOff()
    { OffScreenRenderingOff_29(); }

  public vtkImageViewer() { super(); }

  public vtkImageViewer(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.0.1-3-armv7h.pkg.tar.xz: vtk/vtkImageViewer.java <==
// java wrapper for vtkImageViewer object
//

package vtk;
import vtk.*;

public class vtkImageViewer extends vtkObject
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native String GetWindowName_2();
  public String GetWindowName()
    { return GetWindowName_2(); }

  private native void Render_3();
  public void Render()
    { Render_3(); }

  private native void SetInputData_4(vtkImageData id0);
  public void SetInputData(vtkImageData id0)
    { SetInputData_4(id0); }

  private native long GetInput_5();
  public vtkImageData GetInput() {
    long temp = GetInput_5();

    if (temp == 0) return null;
    return (vtkImageData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetInputConnection_6(vtkAlgorithmOutput id0);
  public void SetInputConnection(vtkAlgorithmOutput id0)
    { SetInputConnection_6(id0); }

  private native int GetWholeZMin_7();
  public int GetWholeZMin()
    { return GetWholeZMin_7(); }

  private native int GetWholeZMax_8();
  public int GetWholeZMax()
    { return GetWholeZMax_8(); }

  private native int GetZSlice_9();
  public int GetZSlice()
    { return GetZSlice_9(); }

  private native void SetZSlice_10(int id0);
  public void SetZSlice(int id0)
    { SetZSlice_10(id0); }

  private native double GetColorWindow_11();
  public double GetColorWindow()
    { return GetColorWindow_11(); }

  private native double GetColorLevel_12();
  public double GetColorLevel()
    { return GetColorLevel_12(); }

  private native void SetColorWindow_13(double id0);
  public void SetColorWindow(double id0)
    { SetColorWindow_13(id0); }

  private native void SetColorLevel_14(double id0);
  public void SetColorLevel(double id0)
    { SetColorLevel_14(id0); }

  private native int[]  GetPosition_15();
  public int[]  GetPosition()
    { return GetPosition_15(); }

  private native void SetPosition_16(int id0,int id1);
  public void SetPosition(int id0,int id1)
    { SetPosition_16(id0,id1); }

  private native void SetPosition_17(int id0[]);
  public void SetPosition(int id0[])
    { SetPosition_17(id0); }

  private native int[]  GetSize_18();
  public int[]  GetSize()
    { return GetSize_18(); }

  private native void SetSize_19(int id0,int id1);
  public void SetSize(int id0,int id1)
    { SetSize_19(id0,id1); }

  private native void SetSize_20(int id0[]);
  public void SetSize(int id0[])
    { SetSize_20(id0); }

  private native long GetRenderWindow_21();
  public vtkRenderWindow GetRenderWindow() {
    long temp = GetRenderWindow_21();

    if (temp == 0) return null;
    return (vtkRenderWindow)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetRenderer_22();
  public vtkRenderer GetRenderer() {
    long temp = GetRenderer_22();

    if (temp == 0) return null;
    return (vtkRenderer)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetImageMapper_23();
  public vtkImageMapper GetImageMapper() {
    long temp = GetImageMapper_23();

    if (temp == 0) return null;
    return (vtkImageMapper)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetActor2D_24();
  public vtkActor2D GetActor2D() {
    long temp = GetActor2D_24();

    if (temp == 0) return null;
    return (vtkActor2D)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetupInteractor_25(vtkRenderWindowInteractor id0);
  public void SetupInteractor(vtkRenderWindowInteractor id0)
    { SetupInteractor_25(id0); }

  private native void SetOffScreenRendering_26(int id0);
  public void SetOffScreenRendering(int id0)
    { SetOffScreenRendering_26(id0); }

  private native int GetOffScreenRendering_27();
  public int GetOffScreenRendering()
    { return GetOffScreenRendering_27(); }

  private native void OffScreenRenderingOn_28();
  public void OffScreenRenderingOn()
    { OffScreenRenderingOn_28(); }

  private native void OffScreenRenderingOff_29();
  public void OffScreenRenderingOff()
    { OffScreenRenderingOff_29(); }

  public vtkImageViewer() { super(); }

  public vtkImageViewer(long id) { super(id); }
  public native long   VTKInit();

}
